@@ -1,7 +1,12 @@
 # Prepare all matrices for the fit, gradient and hessian of varcov models:
 prepare_varcov <- function(x, model){
   # New model:
-  newMod <- updateModel(x,model,updateMatrices = FALSE)
+  if (model@cpp){
+    newMod <- updateModel_cpp(x,model,FALSE)
+  } else {
+    newMod <- updateModel(x,model,updateMatrices = FALSE)  
+  }
+  
   
   # Number of groups:
   nGroup <- nrow(model@sample@groups)
@@ -13,10 +18,15 @@ prepare_varcov <- function(x, model){
   nPerGroup <- model@sample@groups$nobs
 
   # Form the model matrices:
-  mats <- formModelMatrices(newMod)
+  # mats <- formModelMatrices(newMod)
   
   # Compute implied matrices:
-  imp <- implied_varcov(newMod, all = FALSE)
+  if (model@cpp){
+    imp <- implied_varcov_cpp(newMod, all = FALSE)  
+  } else {
+    imp <- implied_varcov(newMod, all = FALSE)
+  }
+  
 
   # Sample stats:
   S <- model@sample@covs
@@ -37,6 +47,11 @@ prepare_varcov <- function(x, model){
     groupModels[[g]]$means <- means[[g]]
     groupModels[[g]]$corinput <- model@sample@corinput
     groupModels[[g]]$meanstructure <- model@meanstructure
+    groupModels[[g]]$cpp <- model@cpp
+    
+    if (is.null( groupModels[[g]]$tau)){
+      groupModels[[g]]$tau <- matrix(NA,1,nVar)
+    }
   
     if (length(thresholds) > 0){
       groupModels[[g]]$thresholds <- thresholds[[g]]      
