@@ -58,6 +58,7 @@ tsdlvm1 <- function(
   centerWithin = FALSE,
   standardize = c("none","z","quantile"),
   verbose = FALSE
+  # bootstrap = FALSE
 ){
   contemporaneous <- match.arg(contemporaneous)
   residual <- match.arg(residual)
@@ -81,6 +82,11 @@ tsdlvm1 <- function(
   # If data is not missing, make augmented data:
   data <- tsData(data, vars = vars2, beepvar = beepvar, dayvar = dayvar, idvar = idvar, groupvar = groups, centerWithin = centerWithin)
   
+  # # Bootstrap the data if needed:
+  # if (bootstrap){
+  #   browser()
+  # }
+  
   # Extract var names:
   if (is.null(groups)){
     vars <- colnames(data)  
@@ -294,8 +300,8 @@ tsdlvm1 <- function(
     # Dstar_between = psychonetrics::duplicationMatrix(nLat,diag = FALSE),  
     
     # Identity matrices:
-    I_y = as(diag(nNode),"dgCMatrix"),
-    I_eta = as(diag(nLat),"dgCMatrix"),
+    I_y = as(diag(nNode),"dMatrix"),
+    I_eta = as(diag(nLat),"dMatrix"),
     # I_within = Diagonal(nLat),
     # I_between = Diagonal(nLat),
     
@@ -306,9 +312,9 @@ tsdlvm1 <- function(
     # A_between = psychonetrics::diagonalizationMatrix(nLat),
     
     # Commutation matrices:
-    C_y_y = as(lavaan::lav_matrix_commutation(nNode, nNode),"dgCMatrix"),
-    C_y_eta = as(lavaan::lav_matrix_commutation(nNode, nLat),"dgCMatrix"),
-    C_eta_eta = as(lavaan::lav_matrix_commutation(nLat, nLat),"dgCMatrix"),
+    C_y_y = as(lavaan::lav_matrix_commutation(nNode, nNode),"dMatrix"),
+    C_y_eta = as(lavaan::lav_matrix_commutation(nNode, nLat),"dMatrix"),
+    C_eta_eta = as(lavaan::lav_matrix_commutation(nLat, nLat),"dMatrix"),
     
     # 
     # C_y_within = as(lavaan::lav_matrix_commutation(nVar, nLat),"sparseMatrix"),
@@ -333,7 +339,7 @@ tsdlvm1 <- function(
   # P matrix:
   # P <- bdiag(Diagonal(nNode*2),sparseMatrix(j=seq_along(inds),i=inds))
   model@extramatrices$P <- bdiag(Diagonal(nNode*2),sparseMatrix(j=seq_along(inds),i=order(inds)))
-  model@extramatrices$P  <- as(as.matrix(model@extramatrices$P), "dgCMatrix")
+  model@extramatrices$P  <- as(as.matrix(model@extramatrices$P), "dMatrix")
   
   # Form the model matrices
   model@modelmatrices <- formModelMatrices(model)
